World Lebanese Cultural Union | Connecting the Lebanese Across the World
Description: The WLCU strives to unite descendants of Lebanese origin and friends of Lebanon into one worldwide organization with the aim to promote and preserve Lebanese culture and heritage and to ensure its spirit for generations to come.
Keywords: Lebanese, Lebanon, Lebanese Culture, Lebanese Community, independence of Lebanon, Beirut, history of Lebanon, Lebanon Photos, Lebanon News, Arabic, Middle East, World Lebanese, Lebanese Emigration, Lebanese People

- Climate Action and Green Competitiveness
- WP Alejandro Kuri Pheres appointed attorney Stephen Stanton the new Chairperson of the Bylaws Committee.
- Water in Lebanon: Matching Myth with Reality from the World Bank report.
- the world fact book: the Lebanese economy
- Lebanese Canadian Marwan Tabbara, a new member of the Canadian parliament
- Lebanese Canadian FAYCAL EL-KHOURY, a new member of Canadian parliament
- Lebanese Canadian EVA NASSIF, a new member of the Canadian parliament
- Attorney Steve Stanton Guidelines about unification: Important matters that ideally should be considered in respect of any future dialogue should it occur again.
- LERC and the Uruguayan Embassy Celebrate 70 Years of Lebanese-Uruguayan Relations
- Charles Habib Malik was a Lebanese philosopher and diplomat.
- Remarks at formal debate of the General Assembly on peace operations. The speech of the Secretary-General Ban Ki-moon, General Assembly, 12 October 2015
- Six Functions of Non-Governmental Organizations in a Democratic Society, By Mark Winfield
- Finding my Lebanon film:Tell your story, support the film, spread the word.
- Finding My Lebanon Short Film, By Mark Abouzeid
- Beirut, a haven of hope and diversity, By EMILY MATHIESON.
- "IN LINE WITH THE DIVINE": THE STRUGGLE FOR GENDER EQUALITY IN LEBANON"
- Dr Guita Hourani's book : 'The Kurds of Lebanon: Socioeconomic Mobility and Political Participation via Naturalization", was translated to Persian language.
- Antoine Menassa attended the International Conference: Information and Culture of Humanitarian Dialogue:
- UNESCO 70 years service to human dignity.
- ...Exactly what activities the WLCU-British Columbia conduct on a daily basis? " When you come to work, what do you do" ?Techsoup canada wanted to know.

#
World Lebanese Cultural Union (WLCU)

###

Latest News

- Charge' d'affair Mr Sami Haddad,Minister Gibran Bassil,Dr Nick kahwaji and the Gibran statue at Queen Elizabeth park, Vancouver, BC 10 july 2015
- The 2015 Board members of the Lebanese Canadian Society of BC ( WLCU Vancouver Chapter) in Belcara Park
- Steve Braks The Lebanese Australian premier of Victoria ,Australia
- Worldwide delegation from the lebanese Diaspora visiting Old Batroun during Diaspora energy conference 2015
- Halifax and BC community will team up to establish the Lebanese Canadian house in Batroun, Lebanon
- Haida Loubnan (This is lebanon),a unique touristic village in lebanon created by Lebanese emigrant from Austria Mr Fady Boudagher
- Family Asfar in a souvenir photo with WLCU-BC Council leaders behind the bench dedicated to Najib Asfar
- MODERN TURKEY STILL DENIES THE ARMENIAN GENOCIDE

[ Presidential/Secretariat News ]

- WP Alejandro Kuri Pheres appointed attorney Stephen Stanton the new Chairperson of the Bylaws Committee.
  you have my full coordination and support and I am looking forward to helping finalize the amendments of our constitution in order to be approved at the next World Congress
  »

- Attorney Steve Stanton Guidelines about unification: Important matters that ideally should be considered in respect of any future dialogue should it occur again.
  I have been asked to submit an article concerning considerations with respect to unification should it arise in the future between the WLCU and any proposed organization that would seek to enter into dialogue and ultimately concluded negotiation as to unification.
  »

[ The International Lebanese Titanic Committee (ILTC) ]
Commemorating the Lebanese aboard the Titanic

- Composer James Horner for 'Titanic,' dies in plane crash
  He was an American composer, conductor and orchestrator of film scores. He was known for the integration of choral and electronic elements in many of his film scores, and for his frequent use of motifs associated with Celtic music
  »
- Radio Canada International-Arabic section. Interview with Dr Nicholas kahwaji about the commemoration of the Lebanese who died abroad the Titanic.
  April 2012-April 2015.Hundred and three years on the sinking of the Titanic:British Columbia to commemorate the Lebanese victims with a range of activities.
  »

[ Recommended Videos ]

Proud to be lebanese: Video created for the Consulate General of Lebanon in Los Angeles

Lebanon on rails : Support the lebanese NGO train Train

[Emigration News] (All News)

- LERC and the Uruguayan Embassy Celebrate 70 Years of Lebanese-Uruguayan Relations
  Under the auspices of Her Excellency Dr. Marta Ines Pizzanelli Ambassador of Uruguay to Lebanon, the Faculty of Law and Political Science (FLPS) and the Lebanese Emigration Research Center (LERC) at Notre Dame University-Louaize (NDU) held an event celebrating 70 years of Lebanese Uruguayan diplomatic relations on October 21, 2015.
  »
- Antoine Menassa attended the International Conference: Information and Culture of Humanitarian Dialogue:
  which took place in Geneva from 24th to 25th of October 2015 at the University of Geneva - Uni Mail, Switzerland.
  »

[UN DPI News]

- Climate Action and Green Competitiveness
  Climate change — and climate action — will have profound consequences on the competitiveness of countries, industries, and businesses alike.
  »

[UN UNESCO News]

- UNESCO 70 years service to human dignity.
  UNESCO is determined that it should be a priority in the post-2015 agenda, which should be human rights-based, with a focus on governance and the rule of law.
  »

[The Cultural Nook of Bahjat Rizk]

- Armenian Genocide: the Redeeming Words By Bahjat Rizk
  To recognize the Armenian genocide...it is a way for Turkey to rehabilitate itself in its own eyes first, then in the eyes of the world. It is to open a new page, fully acknowledging its past and resolutely turning to the future to become again a great nation.
  »
- Universality and Specificity of Cultures
  We will never know how one goes from being an executioner to being a victim, and vice versa. We will never know to what extent people are driven by humanist idealism or by opportunistic ideology.
  »

In The News
[Economy & Business]

- Water in Lebanon: Matching Myth with Reality from the World Bank report.
  A large majority of those living in Lebanon only have access to water for a few hours per day. The little water they do receive from public infrastructure is generally perceived to be of poor quality.
  »
- the world fact book: the Lebanese economy
  Spillover from the Syrian conflict, including the influx of more than 1.5 million Syrian refugees, has increased internal tension and slowed economic growth to the 1-2% range in 2011-13, after four years of averaging 8% growth.
  »

[Culture, Literature & Books]

- "IN LINE WITH THE DIVINE": THE STRUGGLE FOR GENDER EQUALITY IN LEBANON"
  A new book by Dr Guita Hourani, Dr Rita Stephan,dedicated to the analysis of gender-related problems through history and in the present.
  »
- Dr Guita Hourani's book : 'The Kurds of Lebanon: Socioeconomic Mobility and Political Participation via Naturalization", was translated to Persian language.
  ...there is a high level of dissatisfaction in the representation of the Kurds in the parliament and the municipal elections.
  »

[Arts]

- Finding my Lebanon film:Tell your story, support the film, spread the word.
  Tax Deductible Donation Your donation is tax deductible!!! Growing Cedars in Air is a fiscally sponsored project of the International Documentary Association (IDA), a 501(c)(3) non profit organization.
  »
- Finding My Lebanon Short Film, By Mark Abouzeid
  "Roots were something I have never known, will never know; not in the US, not in Hong Kong, not in Tuscany. I was born to travel, to embrace new languages and cultures, to reject attachment"
  »

Various publications

- Khayrallah Center February Newsletter
  Read more »

- DESANewsJuly2015
  Read more »

- The NGO Reporter - June 2013
  Read more »

- CEDAR LEAF NOVEMBER
  Read more »

- e-chronicle, issue 25_Summer 2015
  Read more »

## Mashriq & Mahjar: Journal of Middle East Migration Studies.

Mashriq & Mahjar: Journal of Middle East Migration Studies

## Lebanese In Ottawa

Latest Issue

##

- About Us
- Events

- Contact Us

- World President
- World Secretary General
- World Board of Trustees

- WLCU NGO Board

- DPI of the UN
- LERC at NDU
- Lebanese Republic

##

##

## The Lebanese Heritage

## Subscribe To The Lebanese Heritage

Name Click to add

Email Click to add

Lebanon Land of Dialogue

sign the Petition now!

Dialogue Lobbying and Interviews Endorsement Objective Opinions Steering Committee |

Culture and Heritage

A Bequest Unearthed, Phoenicia, Encyclopedia Phoeniciana. World's largest web compilation of Phoenician resources & studies 1,900 pages with more than one million visitors per year and referenced by 90,000 in-coming links.

Lebanese People - Profiles

- Lebanese Canadian Marwan Tabbara, a new member of the Canadian parliament
  He credits his family for shaping him into a compassionate individual who cares deeply about the world around him. He is committed to real change and a prosperous future for the families
  »
- Lebanese Canadian FAYCAL EL-KHOURY, a new member of Canadian parliament
  He provides a bridge between the many cultural and religious communities in the riding and he has been tremendously effective at fostering the integration of refugees and new immigrants to the Quebec society.
  »
- Lebanese Canadian EVA NASSIF, a new member of the Canadian parliament
  Her fervent hope is to devote her passion to defending the interests of all citizens of the Vimy riding on Parliament Hill in Ottawa.
  »
- Charles Habib Malik was a Lebanese philosopher and diplomat.
  Malik represented Lebanon at the San Francisco conference at which the United Nations was founded. He served as a rapporteur for the Commission on Human Rights in 1947 and 1948, when he became President of the Economic and Social Council ( ECOSOC).
  »
- A grand farewell: Dame Marie Bashir on public, private life and the 'extraordinary' Australian spirit
  "The most wonderful childhood being born in Narrandera, in the view of the canal and the plain to the great river,my brother and sister-in-law still live in that house - and it's embedded very much in my heart, that childhood...
  »

Stay Connected